@@ -1,6 +1,6 @@
 from airflow_commons.logger import LOGGER
 
-from airflow_commons.internal.file_utils import read_sql
+from airflow_commons.internal.util.file_utils import read_sql
 
 from airflow_commons.internal.mysql.auth import get_db_engine
 from airflow_commons.internal.mysql.core import upsert
